@@ -5,16 +5,16 @@ A Python package for extracting polynomial patterns from time series data
 to create meaningful features for machine learning models.
 """
 
-from .core import PatternOptimizer
-from .models import LightGBMModel, get_model, evaluate_model_performance
+from .core import feature_extraction
+from .models import LightGBMModel
+from .data import load_remc_data
 
-__version__ = "0.1.0"
+__version__ = "0.2.6"
 __author__ = "Jonas Wolber"
 __email__ = "jonascw@web.de"
 
 __all__ = [
-    "PatternOptimizer",
-    "LightGBMModel", 
-    "get_model",
-    "evaluate_model_performance"
-]
+    "feature_extraction",
+    "LightGBMModel",
+    "load_remc_data"
+]
\ No newline at end of file
